@@ -35,7 +35,9 @@
 #include <interfaces/devicesmodel.h>
 #include <interfaces/dbusinterfaces.h>
 
-K_PLUGIN_FACTORY(SendFileItemActionFactory, registerPlugin<SendFileItemAction>();)
+#include <dbushelper.h>
+
+K_PLUGIN_CLASS_WITH_JSON(SendFileItemAction, "kdeconnectsendfile.json")
 
 Q_LOGGING_CATEGORY(KDECONNECT_FILEITEMACTION, "kdeconnect.fileitemaction")
 
@@ -72,7 +74,7 @@ QList<QAction*> SendFileItemAction::actions(const KFileItemListProperties& fileI
     }
 
     if (actions.count() > 1) {
-        QAction* menuAction = new QAction(QIcon::fromTheme(QStringLiteral("preferences-system-network")), i18n("Send via KDE Connect"), parentWidget);
+        QAction* menuAction = new QAction(QIcon::fromTheme(QStringLiteral("kdeconnect")), i18n("Send via KDE Connect"), parentWidget);
         QMenu* menu = new QMenu(parentWidget);
         menu->addActions(actions);
         menuAction->setMenu(menu);
@@ -90,9 +92,9 @@ void SendFileItemAction::sendFile()
     const QList<QUrl> urls = sender()->property("urls").value<QList<QUrl>>();
     QString id = sender()->property("id").toString();
     for (const QUrl& url : urls) {
-        QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kdeconnect"), "/modules/kdeconnect/devices/"+id+"/share", QStringLiteral("org.kde.kdeconnect.device.share"), QStringLiteral("shareUrl"));
+        QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kdeconnect"), QStringLiteral("/modules/kdeconnect/devices/") + id + QStringLiteral("/share"), QStringLiteral("org.kde.kdeconnect.device.share"), QStringLiteral("shareUrl"));
         msg.setArguments(QVariantList() << url.toString());
-        QDBusConnection::sessionBus().call(msg);
+        DBusHelper::sessionBus().asyncCall(msg);
     }
 }
 
