@@ -15,7 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "remotecontrolplugin.h"
@@ -30,7 +30,7 @@
 
 #include <core/device.h>
 
-K_PLUGIN_FACTORY_WITH_JSON( KdeConnectPluginFactory, "kdeconnect_remotecontrol.json", registerPlugin< RemoteControlPlugin >(); )
+K_PLUGIN_CLASS_WITH_JSON(RemoteControlPlugin, "kdeconnect_remotecontrol.json")
 
 Q_LOGGING_CATEGORY(KDECONNECT_PLUGIN_REMOTECONTROL, "kdeconnect.plugin.remotecontrol")
 
@@ -44,22 +44,22 @@ RemoteControlPlugin::~RemoteControlPlugin()
 
 void RemoteControlPlugin::moveCursor(const QPoint &p)
 {
-    NetworkPackage np(PACKAGE_TYPE_MOUSEPAD_REQUEST, {
-        {"dx", p.x()},
-        {"dy", p.y()}
+    NetworkPacket np(PACKET_TYPE_MOUSEPAD_REQUEST, {
+        {QStringLiteral("dx"), p.x()},
+        {QStringLiteral("dy"), p.y()}
     });
-    sendPackage(np);
+    sendPacket(np);
 }
 
 void RemoteControlPlugin::sendCommand(const QString &name, bool val)
 {
-    NetworkPackage np(PACKAGE_TYPE_MOUSEPAD_REQUEST, {{name, val}});
-    sendPackage(np);
+    NetworkPacket np(PACKET_TYPE_MOUSEPAD_REQUEST, {{name, val}});
+    sendPacket(np);
 }
 
 QString RemoteControlPlugin::dbusPath() const
 {
-    return "/modules/kdeconnect/devices/" + device()->id() + "/remotecontrol";
+    return QStringLiteral("/modules/kdeconnect/devices/") + device()->id() + QStringLiteral("/remotecontrol");
 }
 
 #include "remotecontrolplugin.moc"
